import requests


class YTKD:
    """ This class is used to encapsulate all attributes and methods pertaining to CNN Classifiers. """

    def __init__(self, url, keywords):
        self.url = url
        self.keywords = keywords
        self.API_ENDPOINT = "http://ytkd-env.eba-jcpqnkgc.ap-south-1.elasticbeanstalk.com/api"
        super().__init__()

    def make_request(self, get_expected_time_only):
        # data to be sent to api
        request_data = {'url': self.url,
                        'keywords': self.keywords,
                        'get_expected_time_only': get_expected_time_only}

        # sending post request and saving response as response object
        r = requests.post(url=self.API_ENDPOINT, data=request_data)
        return r.json()

    def get_expected_time(self):
        return self.make_request(get_expected_time_only=True)

    def get_results(self):
        return self.make_request(get_expected_time_only=False)



import setuptools

with open("README.md", "r") as fh:
    long_description = fh.read()

setuptools.setup(
    name="ytkd_api",
    version="0.0.3",
    author="Ali Haider",
    author_email="alinisarhaider@gmail.com",
    description="A Python wrapper for YouTube Key word detection API. ",
    long_description=long_description,
    long_description_content_type="text/markdown",
    py_modules=["ytkd_api"],
    package_dir={'': 'src'},
    url="https://github.com/alinisarhaider/ytkd_api",
    install_requires=['requests'],
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    python_requires='>=3.6',
)
